# Vanilla Dotfiles

This contains the baseline standard for dotfiles.

Each machine repository maintains its own independent dotfiles,
so having this vanilla repository as a submodule is for 
the convenience of comparing the baseline dotfiles
to the machine's specific dotfiles. (These are not 
programmatically used.)


### Table of Contents

* [Machine Dotfiles Repositories](#machine)
* [Inspiration](#inspiration)
* [Installation](#installation)
    * [Step 1](#step1)
    * [Step 2](#step2)
    * [Step 3](#step3)
    * [Step 4](#step4)
    * [Step 5](#step5)
    * [Step 6](#step6)
* [Setting PATH](#path)
* [Custom Commands Without Committing](#custom)

<br />
<br />

<a name="machine"></a>
## Machine Dotfiles Repositories

Repositories containing machine-specific dotfiles:

* [debian](https://charlesreid1.com:3000/dotfiles/debian)
* [kali](https://charlesreid1.com:3000/dotfiles/kali)
* [mac](https://charlesreid1.com:3000/dotfiles/mac)
* [rpi](https://charlesreid1.com:3000/dotfiles/rpi)

<br />
<br />

<a name="inspiration"></a>
## Inspiration

The baseline dotfiles come from two sources:

* [mathiasbyens/dotfiles](https://github.com/mathiasbynens/dotfiles)
* [charlesreid1/yargwid](https://github.com/charlesreid1/yargwid)

If I include Mathias' thanks section, there are 
a lot more people:

* @ptb and [his _macOS Setup_ repository](https://github.com/ptb/mac-setup)
* [Ben Alman](http://benalman.com/) and his [dotfiles repository](https://github.com/cowboy/dotfiles)
* [Cătălin Mariș](https://github.com/alrra) and his [dotfiles repository](https://github.com/alrra/dotfiles)
* [Gianni Chiappetta](https://butt.zone/) for sharing his [amazing collection of dotfiles](https://github.com/gf3/dotfiles)
* [Jan Moesen](http://jan.moesen.nu/) and his [ancient `.bash_profile`](https://gist.github.com/1156154) + [shiny _tilde_ repository](https://github.com/janmoesen/tilde)
* [Lauri 'Lri' Ranta](http://lri.me/) for sharing [loads of hidden preferences](http://osxnotes.net/defaults.html)
* [Matijs Brinkhuis](https://matijs.brinkhu.is/) and his [dotfiles repository](https://github.com/matijs/dotfiles)
* [Nicolas Gallagher](http://nicolasgallagher.com/) and his [dotfiles repository](https://github.com/necolas/dotfiles)
* [Sindre Sorhus](https://sindresorhus.com/)
* [Tom Ryder](https://sanctum.geek.nz/) and his [dotfiles repository](https://sanctum.geek.nz/cgit/dotfiles.git/about)
* [Kevin Suttle](http://kevinsuttle.com/) and his [dotfiles repository](https://github.com/kevinSuttle/dotfiles) and [macOS-Defaults project](https://github.com/kevinSuttle/macOS-Defaults), which aims to provide better documentation for [`~/.macos`](https://mths.be/macos)
* [Haralan Dobrev](https://hkdobrev.com/)
* Anyone who [contributed a patch](https://github.com/mathiasbynens/dotfiles/contributors) or [made a helpful suggestion](https://github.com/mathiasbynens/dotfiles/issues)

<br />
<br />

<a name="installation"></a>
## Installation

Steps:

1. Clone this repository
2. (Optional) Make modifications as needed
3. Run the pre-bootstrap script
4. Modify the machine hostname
5. Run the bootstrap script
6. (Optional) Install software

Vanilla dotfiles repo does not make any assumptions about
package managers, platforms, or operating systems, so it does 
not try to install any softare.

That is all taken care of in the machine dotfiles repositories.

<a name="step1"></a>
### Step 1: Clone the Repo

```
git clone https://charlesreid1.com:3000/dotfiles/vanilla.git 
```

<a name="step2"></a>
### Step 2: (Optional) Make Modifications

Make modifications to files as needed using a text editor like vim.

<a name="step3"></a>
### Step 3: Run the Pre-Bootstrap Script

This changes your shell to bash and makes space for vim dotfiles.

It is a good idea to use a modern and standard version of Bash.

On a Mac, use the Homebrew version of bash at `/usr/local/bin/bash`
and not the system bash.

On -nix machines, use `/bin/bash` and not `/bin/sh`.

```
./pre_bootstrap.sh
```

<a name="step4"></a>
### Step 4: Modify the Machine Hostname

Set the machine host name using `set_machine_name.sh`.
This script makes no assumptions about platform,
so it tries to determine your OS and act accordingly.

```
./set_machine_name.sh
```

It will prompt you for the hostname you want to set.

<a name="step5"></a>
### Step 5: Run the Bootstrap Script

Run the bootstrap script, which will ask for your confirmation
and will then copy all of the dotfiles in this directory to 
your home directory. This will overwrite any existing dotfiles.

```
./bootstrap.sh
```

<a name="step6"></a>
### Step 6: (Optional) Install Software

Use [Homebrew](https://charlesreid1.com/wiki/Homebrew) or [Aptitude](https://charlesreid1.com/wiki/Aptitude) or [Opkg](https://charlesreid1.com/wiki/OpenWrt/Opkg) or some other package manager to install software.

<br />
<br />
<br />

<a name="path"></a>
## Setting `$PATH`

The `$PATH` variable controls where the shell will look for programs.
To modify your `$PATH` variable, you can do two things:
* Put path modifications in `$HOME/.path` 
* Add path modifications to `$HOME/.bash_profile`

The `~/.path` file is run before other files like `.aliases`, so it should pick up the correct version of binaries 
in subsequent sourced dotfiles.

An example `~/.path` file might include:

```bash
export PATH="/custom/program/path/bin:$PATH"
```

<br />
<br />

<a name="custom"></a>
## Custom Commands Without Committing

Use the `~/.extra` file to set any extra settings without committing them to the repository.

```bash
# Git credentials
# Not in the repository
# This prevents people from using my github credentials
GIT_AUTHOR_NAME="Charles Reid"
GIT_AUTHOR_EMAIL="charlesreid1@gmail.com"

GIT_COMMITTER_NAME="$GIT_AUTHOR_NAME"
GIT_COMMITTER_EMAIL="$GIT_AUTHOR_EMAIL"

git config --global user.name "$GIT_AUTHOR_NAME"
git config --global user.email "$GIT_AUTHOR_EMAIL"
```

Also use the `.extra` file to override settings, functions, etc from other dotfiles.
